bayespy.inference.vmp.nodes.stochastic.Stochastic.unobserve
===========================================================

.. currentmodule:: bayespy.inference.vmp.nodes.stochastic

.. automethod:: Stochastic.unobserve